=========================================================
I <3 pyladies: supporting women who code t-shirts
=========================================================

A shirt designed for both women and men to wear. 

Printing Instructions
---------------------

Use a high-quality t-shirt stock.  Low-quality t-shirts can cheapen the feel of an event.

We used American Apparel:

* Classic Girl - sizes run small, so order more l/xl than usual
* Standard American - nice unisex shirt that looks great on either gender

Colors:

* White ink on a dark shirt.  We used asphalt-colored shirts; you'll want to pick a different color to identify your group as a different chapter.  Try eggplant, navy blue, black, or another color that you like.

Files:

* PDF: most printer-friendly version
* SVG: can be edited in Inkscape
* JPG: for sticking on the website & blogs if needed
